@@ -1,17 +1,14 @@
-/***************************************************************************
- *   Copyright (C) 2006 by Matthew Williams    <matt@milliams.com>         *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006 Matthew Williams <matt@milliams.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "gameboardscene.h"
 
 #include "highlightanimation.h"
 
-#include <math.h>
+#include <cmath>
 
 #include <QGraphicsSceneMouseEvent>
 #include <QGraphicsEllipseItem>
@@ -186,7 +183,7 @@ void GameBoardScene::addLineToIndex(const QList<QGraphicsEllipseItem *> &pointPa
         return;
     }
 
-    emit lineDrawn(index);  //addLineToIndex(index);
+    Q_EMIT lineDrawn(index);  //addLineToIndex(index);
 }
 
 QList<QGraphicsEllipseItem *> GameBoardScene::getTwoNearestPoints(const QPointF &pos) const
